@@ -6,8 +6,9 @@ TAR=$3
 
 # clean up the upstream tarball
 tar -x -z -f $TAR
-tar -c -z -f $TAR --exclude '*.jar' --exclude '*/javadocs/*' trove-*/
-rm -rf trove-*/
+mv $2/ trove-$2/
+tar -c -z -f $TAR --exclude '*.jar' --exclude '*/javadocs/*' trove-$2/
+rm -rf trove-$2/
 
 # move to directory 'tarballs'
 if [ -r .svn/deb-layout ]; then
